==> OpenCL-0.7.8.tgz: OpenCL-0.7.8/include/triple.h <==
/*************************************************
* Triple EDE Mode Header File                    *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#ifndef OPENCL_TRIPLE_EDE_MODE_H__
#define OPENCL_TRIPLE_EDE_MODE_H__

#include <opencl/opencl.h>

namespace OpenCL {

/*************************************************
* Triple Key EDE Mode                            *
*************************************************/
template<typename B>
class Triple : public BlockCipher
   {
   public:
      static std::string name() { return "Triple<" + B::name() + ">"; }
      static const u32bit BLOCKSIZE = B::BLOCKSIZE,
                          KEYLENGTH = 3*B::KEYLENGTH;
      void set_key(const byte[], u32bit = KEYLENGTH) throw(InvalidKeyLength);
      void clear() throw() { C1.clear(); C2.clear(); C3.clear(); }
      Triple() : BlockCipher(name(), BLOCKSIZE, 3, KEYLENGTH, 3) {}
   private:
      void enc(const byte in[BLOCKSIZE], byte out[BLOCKSIZE]) const
         { C1.encrypt(in, out); C2.decrypt(out); C3.encrypt(out); }
      void dec(const byte in[BLOCKSIZE], byte out[BLOCKSIZE]) const
         { C3.decrypt(in, out); C2.encrypt(out); C1.decrypt(out); }
      B C1, C2, C3;
   };

/*************************************************
* Triple Key EDE Mode Key Setup                  *
*************************************************/
template<typename B>
void Triple<B>::set_key(const byte key[], u32bit length)
   throw(InvalidKeyLength)
   {
   if(!valid_keylength(length))
      throw InvalidKeyLength(name(), length);
   C1.set_key(key                   , length / 3);
   C2.set_key(key +     (length / 3), length / 3);
   C3.set_key(key + 2 * (length / 3), length / 3);
   }

}

#endif

==> OpenCL-0.7.10.tgz: OpenCL-0.7.10/include/triple.h <==
/*************************************************
* Triple EDE Mode Header File                    *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#ifndef OPENCL_TRIPLE_EDE_MODE_H__
#define OPENCL_TRIPLE_EDE_MODE_H__

#include <opencl/opencl.h>

namespace OpenCL {

/*************************************************
* Triple Key EDE Mode                            *
*************************************************/
template<typename B>
class Triple : public BlockCipher
   {
   public:
      static std::string name() { return "Triple<" + B::name() + ">"; }
      static const u32bit BLOCKSIZE = B::BLOCKSIZE,
                          KEYLENGTH = 3*B::KEYLENGTH;
      void set_key(const byte[], u32bit = KEYLENGTH) throw(Invalid_Key_Length);
      void clear() throw() { C1.clear(); C2.clear(); C3.clear(); }
      Triple() : BlockCipher(name(), BLOCKSIZE, 3, KEYLENGTH, 3) {}
   private:
      void enc(const byte in[BLOCKSIZE], byte out[BLOCKSIZE]) const
         { C1.encrypt(in, out); C2.decrypt(out); C3.encrypt(out); }
      void dec(const byte in[BLOCKSIZE], byte out[BLOCKSIZE]) const
         { C3.decrypt(in, out); C2.encrypt(out); C1.decrypt(out); }
      B C1, C2, C3;
   };

/*************************************************
* Triple Key EDE Mode Key Setup                  *
*************************************************/
template<typename B>
void Triple<B>::set_key(const byte key[], u32bit length)
   throw(Invalid_Key_Length)
   {
   if(!valid_keylength(length))
      throw Invalid_Key_Length(name(), length);
   C1.set_key(key                   , length / 3);
   C2.set_key(key +     (length / 3), length / 3);
   C3.set_key(key + 2 * (length / 3), length / 3);
   }

}

#endif
